Test coverage report: markupmirror.markup.plaintext

# markupmirror.markup.plaintext: 12 total statements, 100.0% covered

Generated: Wed 2012-04-11 05:19 CDT

Source file: /home/buechler/Sites/django-markupmirror/markupmirror/markup/plaintext.py

Stats: 7 executed, 0 missed, 5 excluded, 15 ignored

1. `from django.utils.html import linebreaks`
2. `from django.utils.html import urlize`
3. `from django.utils.translation import ugettext_lazy as _`
4. ``
5. `from markupmirror.markup.base import BaseMarkup`
6. `from markupmirror.markup.base import register_markup`
7. ``
8. ``
9. `class PlainTextMarkup(BaseMarkup):`
10. `"""Markup transformer for plain-text content.`
11. ``
12. `This uses Django's ``urlize`` and ``linebreaks`` utitlies to convert URLs`
13. `in the text to clickable links and linebreaks to ``<p>`` and ``<br />```
14. `elements respectively.`
15. ``
16. `"""`
17. `codemirror_mode = ''`
18. `title = _(u"Plain text")`
19. ``
20. `def convert(self, markup):`
21. `return urlize(linebreaks(markup))`
22. ``
23. ``
24. `register_markup(PlainTextMarkup)`
25. ``
26. ``
27. `__all__ = ('PlainTextMarkup',)`